Module apt — Inmanta 2017.3dev documentation

# Module apt

> - License: Apache 2.0
> - Version: 0.4.1
> - Author: Inmanta <code@inmanta.com>
> - This module requires compiler version 2017.1 or higher
> - Upstream project: https://github.com/inmanta/apt.git

## Entities

entity `apt::Repository`

  Parents: `std::Entity`

  An apt repository

  attribute string `repo`
  attribute string `base_url`
  attribute bool `trusted`=False
  attribute string `release`
  attribute string `name`
  relation std::Host `host` [1]

    other end: `std::Host.repository [0:*]`

  The following implementations are defined for this entity:

  > - `apt::simpleRepo`

  The following implements statements select implementations for this entity:

  > - `apt::simpleRepo`

## Implementations

implementation `apt::simpleRepo`

## Handlers

class `apt.` `AptPackage`

  > A Package handler that uses apt

  > TODO: add latest support

  - Handler name `apt`
  - Handler for entity `std::Package`